@@ -7,16 +7,19 @@
 #' @param region (character) Geographic region, one of "amer", "apac",
 #' or "emea"
 #' @param year (numeric/integer) year member joined DataCite
-#' @inheritParams dc_member
+#' @param offset (numeric/integer) result offset, the record to start at
+#' @param rows (numeric/integer) results per page
+#' @param ... curl options passed on to [crul::HttpClient]
 #' @seealso [dc_member()]
 #' @family rest api methods
 #' @examples \dontrun{
 #' dc_members(query = "ands")
 #' }
 dc_members <- function(query = NULL, member_type = NULL, region = NULL,
-	year = NULL,  ...) {
+	year = NULL, offset = 0, rows = 25, ...) {
 
 	args <- dc_compact(list(query = query, `member-type` = member_type,
-		region = region, year = year))
+		region = region, year = year, `page[offset]` = offset,
+    `page[size]` = rows))
   dc_rest_GET("members", args = args, ...)
 }
