@@ -11,14 +11,6 @@ test_that("dc_oai_listsets", {
   expect_is(aa$setName, "character")
 })
 
-test_that("dc_oai_listsets - curl options", {
-  skip_on_cran()
-
-  library("httr")
-
-  expect_error(dc_oai_listsets(config = timeout(0.001)), "Timeout was reached")
-})
-
 test_that("dc_oai_listsets fails well", {
   skip_on_cran()
 
